==> heimdall-flash_2.0.2.orig.tar.gz: Heimdall-v2.0.2/heimdall/source/TotalBytesPacket.h <==
/* Copyright (c) 2010-2017 Benjamin Dobell, Glass Echidna
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:
 
 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.*/

#ifndef TOTALBYTESPACKET_H
#define TOTALBYTESPACKET_H

// Heimdall
#include "SessionSetupPacket.h"

namespace Heimdall
{
	class TotalBytesPacket : public SessionSetupPacket
	{
		private:

			unsigned long totalBytes;

		public:

			TotalBytesPacket(unsigned long totalBytes) : SessionSetupPacket(SessionSetupPacket::kTotalBytes)
			{
				this->totalBytes = totalBytes;
			}

			unsigned long GetTotalBytes(void) const
			{
				return (totalBytes);
			}

			void Pack(void)
			{
				SessionSetupPacket::Pack();

				PackInteger(SessionSetupPacket::kDataSize, totalBytes);
				PackInteger(SessionSetupPacket::kDataSize + 4, totalBytes>>32);
			}
	};
}

#endif

==> heimdall-flash_2.1.0.orig.tar.gz: Heimdall-v2.1.0/heimdall/source/TotalBytesPacket.h <==
/* Copyright (c) 2010-2017 Benjamin Dobell, Glass Echidna
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:
 
 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.*/

#ifndef TOTALBYTESPACKET_H
#define TOTALBYTESPACKET_H

// C++ Standard Library
#include <cstdint>

// Heimdall
#include "SessionSetupPacket.h"

namespace Heimdall
{
	class TotalBytesPacket : public SessionSetupPacket
	{
		private:

			uint64_t totalBytes;

		public:

			TotalBytesPacket(uint64_t totalBytes) : SessionSetupPacket(SessionSetupPacket::kTotalBytes)
			{
				this->totalBytes = totalBytes;
			}

			uint64_t GetTotalBytes(void) const
			{
				return (totalBytes);
			}

			void Pack(void)
			{
				SessionSetupPacket::Pack();

				PackInteger(SessionSetupPacket::kDataSize, totalBytes);
				PackInteger(SessionSetupPacket::kDataSize + 4, totalBytes>>32);
			}
	};
}

#endif
